@@ -28,13 +28,13 @@
 #include <string.h>
 
 # include <unistd.h>
-# include <sys/unistd.h>
 #include <sys/types.h>
 # include <getopt.h>
 # include <inttypes.h>
 # include <signal.h>
+#if HAVE_SYS_SIGNAL_H
 # include <sys/signal.h>
-
+#endif
 #include <sixel.h>
 
 /* output version info to STDOUT */
@@ -312,6 +312,7 @@ void show_help(void)
             );
 }
 
+#if HAVE_SYS_SIGNAL_H
 
 static int signaled = 0;
 
@@ -321,6 +322,7 @@ signal_handler(int sig)
     signaled = sig;
 }
 
+#endif
 
 int
 main(int argc, char *argv[])
@@ -414,6 +416,8 @@ main(int argc, char *argv[])
         }
     }
 
+#if HAVE_SYS_SIGNAL_H
+
     /* set signal handler to handle SIGINT/SIGTERM/SIGHUP */
     signal(SIGINT, signal_handler);
     signal(SIGTERM, signal_handler);
@@ -423,6 +427,8 @@ main(int argc, char *argv[])
         goto error;
     }
 
+#endif
+
     if (optind == argc) {
         status = sixel_encoder_encode(encoder, NULL);
         if (SIXEL_FAILED(status)) {
